aboutsummaryrefslogtreecommitdiffstats
path: root/objects.go
diff options
context:
space:
mode:
authorMáximo Cuadros <mcuadros@gmail.com>2015-10-31 01:14:03 +0100
committerMáximo Cuadros <mcuadros@gmail.com>2015-10-31 01:14:03 +0100
commitc6349552c1c54ea114b92ae23fc840f68f6551f4 (patch)
tree6fbaf514ae9caf8241a0b9dfc3709d60942876c5 /objects.go
parentfe1fc1aa7dca3e0f6e54ab17f0acfa45f269e58c (diff)
downloadgo-git-c6349552c1c54ea114b92ae23fc840f68f6551f4.tar.gz
internal -> core
Diffstat (limited to 'objects.go')
-rw-r--r--objects.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/objects.go b/objects.go
index 49c0e9e..351a022 100644
--- a/objects.go
+++ b/objects.go
@@ -6,19 +6,19 @@ import (
"strconv"
"time"
- "gopkg.in/src-d/go-git.v2/internal"
+ "gopkg.in/src-d/go-git.v2/core"
)
// Blob is used to store file data - it is generally a file.
type Blob struct {
- Hash internal.Hash
+ Hash core.Hash
Size int64
- obj internal.Object
+ obj core.Object
}
-// Decode transform an internal.Object into a Blob struct
-func (b *Blob) Decode(o internal.Object) error {
+// Decode transform an core.Object into a Blob struct
+func (b *Blob) Decode(o core.Object) error {
b.Hash = o.Hash()
b.Size = o.Size()
b.obj = o